// Requests.java
// Modified by: Maria Kazandjieva, marykaz@hotmail.com, Summer 2005

// This class has been modified from its original version; it contains hardcoded commands that can be sent to the RF reader

import javax.comm.*;
import java.io.*;
import java.util.*;

/* The Requests class contains all the requests that are sent to the reader throughout the function of the code */

public class Requests {

		// this straing array holds the IDs of the tags that can be used with this program
		public static String[] tagIDs = {"E007000001F9B330",
							 				"E00781BCC1980F62",
											"E004010002ABE5BA",
											"E004010001D6F86A",
											"E007000001F99F1A"};


	//constructor
	public Requests() {}

	//this method sends the select tag command to the reader
	public static void selectTag(SerialPort myPort, CommPort thePort) throws IOException, NoSuchPortException, PortInUseException,
				UnsupportedCommOperationException {
		DataOutputStream outStream;
		//create output stream
		outStream = new DataOutputStream(thePort.getOutputStream());
		//send select tag command to the reader
		byte [] ba = {(byte)0x02, (byte)0x05, (byte)0x20, (byte)0x14,  (byte)0x01, (byte)0x8E, (byte)0x14};
		outStream.write(ba);
		//close the output stream
		outStream.close();
	}


	//this method writes data to tag
		public static int writeTag(SerialPort myPort, CommPort thePort) throws IOException, NoSuchPortException, PortInUseException,
					UnsupportedCommOperationException {

			int success=0;

			Requests req = new Requests();
			readResponse read = new readResponse();
			responseHandler respHand = new responseHandler();

			DataOutputStream outStream;
			//create output stream
			outStream = new DataOutputStream(thePort.getOutputStream());

			req.selectTag(myPort, thePort);
			StringBuffer stringBuff = read.readResponse(myPort, thePort);

			//get the response code from the response
			String respCode = respHand.getResponseCode(stringBuff);
			if (respCode.equals("14")) {

				success = 1;
				String currentTagID = respHand.getTagID(stringBuff);

				//System.out.println("current TagID is : " + currentTagID);


				//send select tag command to the reader

			if (currentTagID.equalsIgnoreCase(tagIDs[0])){
				//System.out.println("Data to be written: 11235813");
				byte[] ba = {(byte)0x02, (byte)0x13, (byte)0x60, (byte)0x44, (byte)0x01,
							(byte)0xE0, (byte)0x07, (byte)0x00, (byte)0x00, (byte)0x01,
							(byte)0xF9, (byte)0xB3, (byte)0x30, (byte)0x00, (byte)0x01,
							(byte)0x11, (byte)0x23, (byte)0x58, (byte)0x13, (byte)0x02,
							(byte)0x23};

				outStream.write(ba);
			}

			else if (currentTagID.equalsIgnoreCase(tagIDs[1])){
				//System.out.println("Data to be written: 13371337");
				byte[] ba = {(byte)0x02, (byte)0x13, (byte)0x60, (byte)0x44, (byte)0x01, (byte)0xE0,
							(byte)0x07, (byte)0x81, (byte)0xBC, (byte)0xC1, (byte)0x98,
							(byte)0x0F, (byte)0x62, (byte)0x00, (byte)0x01, (byte)0x13,
							(byte)0x37, (byte)0x13, (byte)0x37, (byte)0x27, (byte)0xA1};
				outStream.write(ba);
				}

			else if (currentTagID.equalsIgnoreCase(tagIDs[2])){
				//System.out.println("Data to be written: 24681012");
				byte[] ba = {(byte)0x02, (byte)0x13, (byte)0x60, (byte)0x44, (byte)0x01,
							 (byte)0xE0, (byte)0x04, (byte)0x01, (byte)0x00,
							(byte)0x02, (byte)0x0A, (byte)0xBE, (byte)0x5B, (byte)0x00,
							(byte)0x01, (byte)0x24, (byte)0x68, (byte)0x10, (byte)0x12,
							(byte)0xFD, (byte)0x76};
				outStream.write(ba);
			}

			else if (currentTagID.equalsIgnoreCase(tagIDs[3])){
				//System.out.println("Data to be written: 13579110");
				byte[] ba = {(byte)0x02, (byte)0x13, (byte)0x60, (byte)0x44, (byte)0x01, (byte)0xE0,
							(byte)0x04, (byte)0x01, (byte)0x00, (byte)0x01, (byte)0xD6,
							(byte)0xF8, (byte)0x6A, (byte)0x00, (byte)0x01, (byte)0x13,
							(byte)0x57, (byte)0x91, (byte)0x10, (byte)0x44, (byte)0x73};
				outStream.write(ba);
			}

			else if (currentTagID.equalsIgnoreCase(tagIDs[4])){
				//System.out.println("Data to be written: 07282005");
				byte[] ba = {(byte)0x02, (byte)0x13, (byte)0x60, (byte)0x44, (byte)0x01,
							(byte)0xE0, (byte)0x07, (byte)0x00, (byte)0x00, (byte)0x01,
							(byte)0xF9, (byte)0x9F, (byte)0x1A, (byte)0x00, (byte)0x01,
							(byte)0x07, (byte)0x28, (byte)0x20, (byte)0x05, (byte)0xEF,
							(byte)0x4B};
				outStream.write(ba);
			}

			else {
				//System.err.println("There was an error identifying the tag.");
				//System.exit(0);
			}
		}

		else {
			//System.out.println("There was an error detecting a tag.");
			//System.exit(0);
		}

			//close the output stream
			outStream.close();
			return (success);

	} // end of write method

	//this method read data from Tag
	public static int readTag(SerialPort myPort, CommPort thePort) throws IOException, NoSuchPortException, PortInUseException,
						UnsupportedCommOperationException {

							int success = 0;

	Requests req = new Requests();
	readResponse read = new readResponse();
	responseHandler respHand = new responseHandler();

	DataOutputStream outStream;
	//create output stream
	outStream = new DataOutputStream(thePort.getOutputStream());

	req.selectTag(myPort, thePort);
	StringBuffer stringBuff = read.readResponse(myPort, thePort);

	//get the response code from the response
	String respCode = respHand.getResponseCode(stringBuff);
	if (respCode.equals("14")) {

		success = 1;

	String currentTagID = respHand.getTagID(stringBuff);

	//System.out.println("currentTagID is : " + currentTagID);


	//send select tag command to the reader

	if (currentTagID.equalsIgnoreCase(tagIDs[0])){
			byte[] ba = {(byte)0x02, (byte)0x0F, (byte)0x60, (byte)0x24,
						(byte)0x01, (byte)0xE0, (byte)0x07, (byte)0x00,
						(byte)0x00,(byte)0x01, (byte)0xF9, (byte)0xB3,
						(byte)0x30, (byte)0x00, (byte)0x01, (byte)0x9D,
						(byte)0x07};
			outStream.write(ba);
	}

	else if (currentTagID.equalsIgnoreCase(tagIDs[1])){
				byte[] ba = {(byte)0x02, (byte)0x0F, (byte)0x60, (byte)0x24,
							(byte)0x01, (byte)0xE0, (byte)0x07, (byte)0x81,
							(byte)0xBC, (byte)0xC1, (byte)0x98, (byte)0x0F,
							(byte)0x62, (byte)0x00, (byte)0x01, (byte)0x5B,
							(byte)0xE0};
				outStream.write(ba);
	}

	else if (currentTagID.equalsIgnoreCase(tagIDs[2])){
				byte[] ba = {(byte)0x02, (byte)0x0F, (byte)0x60, (byte)0x24,
							(byte)0x01, (byte)0xE0, (byte)0x04, (byte)0x01,
							(byte)0x00, (byte)0x02, (byte)0x0A, (byte)0xBE,
							(byte)0x5B, (byte)0x00, (byte)0x01, (byte)0xE3,
							(byte)0xCC};
				outStream.write(ba);
	}

	else if (currentTagID.equalsIgnoreCase(tagIDs[3])){
				byte[] ba = {(byte)0x02, (byte)0x0F, (byte)0x60, (byte)0x24,
							(byte)0x01, (byte)0xE0, (byte)0x04, (byte)0x01,
							(byte)0x00, (byte)0x01, (byte)0xD6, (byte)0xF8,
							(byte)0x6A, (byte)0x00, (byte)0x01, (byte)0xE6,
							(byte)0xE9};
				outStream.write(ba);
	}

	else if (currentTagID.equalsIgnoreCase(tagIDs[4])){
				byte[] ba = {(byte)0x02, (byte)0x0F, (byte)0x60, (byte)0x24,
							(byte)0x01, (byte)0xE0, (byte)0x07, (byte)0x00,
							(byte)0x00, (byte)0x01, (byte)0xF9, (byte)0x9F,
							(byte)0x1A, (byte)0x00, (byte)0x01, (byte)0xF5,
							(byte)0x21};
				outStream.write(ba);
	}
	else {
				//System.err.println("There was an error identifying the tag.");
				//System.exit(0);
			}
	}
		else {
				//System.err.println("There was an error detecting a tag.");
				//System.exit(0);
			}



	//close the output stream
	outStream.close();
	return (success);
	} // end of read method

} // end of class