// Server.java
// Written by: Maria Kazandjieva, marykaz@hotmail, Summer 2005

// This file creates the visual display window of the server side.
/*
There are buttons for stopping and starting the server, as well as a button for displaying the data.
The methods that are triggered by the buttons are in a separate class. They run in a separate thread.
*/

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import javax.microedition.io.*;
import java.io.*;
import javax.bluetooth.*;

public class Server implements ActionListener{

	// declare and initiate variables
	JButton startButton = new JButton("Start Server");
	JButton stopButton = new JButton("Stop Server");
	JButton displayButton = new JButton("Display Data");

	JTextArea textarea = new JTextArea("",20, 40);

	JFrame frame;

	private int numberNodes;
	private Node[] nodes_array;

	double[] data;
	double[] energy;
	int[] x;
	int[] y;

	private boolean keepRunning = true;
	RunServer runServer = new RunServer(numberNodes, data, energy, x, y, this);

	public  Server(){

		// use Java Swing components to create a GUI
		frame = new JFrame("Server ");
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

		JScrollPane scrollPane = new JScrollPane(textarea);
		textarea.setEditable(false);

		Container cp = frame.getContentPane();
		cp.setLayout(new BorderLayout());

		JPanel buttonsPane = new JPanel();
		buttonsPane.setLayout(new GridLayout(1,3));

		startButton.addActionListener(this);
		buttonsPane.add(startButton);

		stopButton.addActionListener(this);
		stopButton.setEnabled(false);
		buttonsPane.add(stopButton);

		displayButton.addActionListener(this);
		displayButton.setEnabled(false);
		buttonsPane.add(displayButton);

		cp.add(buttonsPane, BorderLayout.NORTH);

		cp.add(scrollPane, BorderLayout.CENTER);

		frame.pack();
		frame.setVisible(true);

	}

	public void actionPerformed(ActionEvent e) {

		// start the server; it will run in a loop until stopped
		if( e.getSource() == startButton){
			startButton.setEnabled(false);
			receiveData();
			displayButton.setEnabled(true);
			stopButton.setEnabled(true);
		}

		// run ChoiceScreen which is the basis for the visual representation of received data
		if( e.getSource() == displayButton){
			new ChoiceScreen();
		}

		// stop the server
		if(e.getSource() == stopButton){
			runServer.stop();
			startButton.setEnabled(true);
			stopButton.setEnabled(false);
		}


		}

	// method to update the text area in the window
	public void updateStatus(String message){
		textarea.append("\n" + message);
	}

	// main mathod for Server class
	public static void main(String[] args) {

		new Server();

	} // end main


	// this method creates a thread to manage the server's functions without freezing the GUI
	public void receiveData(){
		Thread t = new Thread (runServer);
		t.start();

	}

}
